request_line

Function request_line 

pub fn request_line(
    max_label_count: usize,
    max_segments: NonZero<usize>,
    query_count_range: RangeInclusive<usize>,
) -> impl Strategy<Value = (HttpRequestLine, String)>
strategy for generating HTTP request line.

Arguments

  • max_label_count: maximum label count to use for domain hosts in case of authority form, origin form and absolute form.
  • max_segments: maximum number of segments that compose the path in case of absolute form and origin form.
  • query_count_range: range of the number of queries to include in case of absolute form and origin form.

Returns

HttpRequestLine and it representation.