Module path

URL path strategies.

Structs

Path
URL path.

Functions

path_absolute
absolute path with no query params and no fragment. #Returns Path and its raw representation.
path_rootless
rootless path with no query params and no fragment.