URL path strategies.
Structs
- Path
- URL path.
Functions
- path_
absolute - absolute path with no query params and no fragment.
#Returns
Pathand its raw representation. - path_
rootless - rootless path with no query params and no fragment.